OC.L10N.register(
    "lib",
    {
    "Unknown filetype" : "ບໍ່ຮູ້ປະເພດຂອງຟາຍ",
    "Invalid image" : "ບໍ່ມີຮູບພາບ",
    "Files" : "ຟາຍ",
    "seconds ago" : "ວິນາທີຜ່ານມາ",
    "Filename contains at least one invalid character" : "ຊື່ຟາຍມີລັກສະນະທີ່ບໍ່ຖືກຕ້ອງ",
    "__language_name__" : "ຂີ້ຕົວະ",
    "Apps" : "ແອັບພລິເຄຊັນ",
    "Settings" : "ການຕັ້ງຄ່າ",
    "Log out" : "ອອກຈາກລະບົບ",
    "Accounts" : "ບັນຊີ",
    "Email" : "ອິເມວ",
    "Twitter" : "Twitter",
    "Website" : "ເວັບໄຊ",
    "Address" : "ທີ່ຢູ່",
    "About" : "ກ່ຽວກັບ",
    "Role" : "ພາລະບົດບາດ",
    "Translate" : "ແປ",
    "Users" : "ຜູ້ໃຊ້"
},
"nplurals=1; plural=0;");
